@@ -1,4 +1,5 @@
 from easypl.learners.base import BaseLearner
-from easypl.learners.classification import ClassificatorLearner
+from easypl.learners.classification import ClassificationLearner
 from easypl.learners.segmentation import SegmentationLearner
 from easypl.learners.recognition import RecognitionLearner
+from easypl.learners.gan import GANLearner
